# Puppeteer Assets [![npm version](https://badge.fury.io/js/puppeteer-assets.svg)](https://badge.fury.io/js/puppeteer-assets) [![Build Status](https://travis-ci.org/andersonba/puppeteer-assets.svg?branch=master)](https://travis-ci.org/andersonba/puppeteer-assets)

> Gets assets metrics using [Puppeteer](https://github.com/googlechrome/puppeteer).

Want to know which scripts are loaded in your page? This module allows you to extract and audit the metrics.

![Gif CLI](resources/cli.gif)

## Set up

```bash
yarn add puppeteer-assets
```

## Usage

Using CLI

```bash
puppeteer-assets www.google.com
```

Using on Node.js

```javascript
const assetsMetrics = require('puppeteer-assets');
const metrics = await assetsMetrics('https://www.andersonba.com');

// metrics
{
  assets: {
    'https://www.andersonba.com/scripts/main.js': {
      mimeType: 'javascript',
      rawMimeType: 'application/javascript',
      type: 'internal',
      gzip: 1621,
      size: 1621
    },
    'https://www.andersonba.com/scripts/vendor.js': {
      mimeType: 'javascript',
      rawMimeType: 'application/javascript',
      type: 'internal',
      gzip: 213438,
      size: 213438
    },
    'https://www.google-analytics.com/analytics.js': {
      mimeType: 'javascript',
      rawMimeType: 'text/javascript',
      type: 'external',
      gzip: 17821,
      size: 44470
    },
    'https://www.google-analytics.com/gtm/js?id=GTM-W7LMQWK&cid=337847530.1572046475': {
      mimeType: 'javascript',
      rawMimeType: 'application/javascript',
      type: 'external',
      gzip: 22779,
      size: 61860
    }
  },
  count: {
    internal: { total: 2, javascript: 2 },
    external: { total: 2, javascript: 2 },
    total: 4
  },
  size: {
    internal: { total: 215059, javascript: 215059 },
    external: { total: 106330, javascript: 106330 },
    total: 321389
  },
  gzip: {
    internal: { total: 215059, javascript: 215059 },
    external: { total: 40600, javascript: 40600 },
    total: 255659
  }
}
```

## Prometheus

Exports assets metrics via HTTP for Prometheus consumption.

![Grafana](resources/grafana.png)

Use [docker image](https://hub.docker.com/r/andersonba/prometheus-assets/):

```bash
docker run --name=prometheus-assets -d -p 3000:3000 andersonba/prometheus-assets
```

Now, in your Prometheus configuration ([/etc/prometheus/prometheus.yml](https://prometheus.io/docs/prometheus/latest/configuration/configuration/)), add a new target.

You can monitor multiple URLs passing `params` each scrape config. [See example](prometheus/prometheus.yml#L12-L37)

If you prefer use a configuration file, create a [config.yml](prometheus/config.example.yml) file. Then, run the container defining
the volume:

```bash
docker run --name=prometheus-assets -v /tmp/config.yml:/app/prometheus/ -d -p 3000:3000 andersonba/prometheus-assets
```

## Reference API

#### `assetsMetrics(url, options)`

##### Parameters

```javascript
url: string;  // Page URL (required)
options: {
  mimeTypes: Array<RegExp | string>;
  mimeTypesPatterns: {
    [name: string]: Array<RegExp | string>;
  },
  internalPatterns: Array<RegExp | string>;
}
```

| Parameter | Description | Type | Default |
|-----------|-------------|------|---------|
| `url` | **Required.** Page URL | `string`
| `options.mimeTypes` |  | `Array<RegExp | string> ` | `['javascript']`
| `options.mimeTypePatterns` |  | `Array<RegExp | string> ` | `{ javascript: ['javascript'], css: ['css'] }`
| `options.internalPatterns` |  | `Array<RegExp | string> ` | `[/^(\/|.\/)/]`

- `url` -
- `options.mimeTypes` - Array of RegExp/String.  _(default: ['javascript'])_
- `options.internalPattern` - String/Regex. Identify scripts as Internal based on RegExp _(Default: null)_
- `options.mimeTypes` - Array of String/RegExp. File types to be matched _(Default: 'javascript')_
