# Prometheus Assets [![docker pulls](https://img.shields.io/docker/pulls/andersonba/prometheus-assets)](https://hub.docker.com/r/andersonba/prometheus-assets) [![docker stars](https://img.shields.io/docker/stars/andersonba/prometheus-assets)](https://hub.docker.com/r/andersonba/prometheus-assets)

Explore and monitor your assets metrics using [Prometheus](https://prometheus.io) and [Grafana](https://grafana.com).

First, you need to set up the exporter server. You can use official docker image [andersonba/prometheus-assets](https://hub.docker.com/r/andersonba/prometheus-assets/).

## Example

You can test all workspace in your machine using [docker-compose](https://docs.docker.com/compose/install/). Running the following command will set up Server, Prometheus and Grafana services.

```
docker-compose up
```

Server http://localhost:3000 • Grafana http://localhost:8080 • Prometheus http://localhost:9090

## Configure

There are two ways to configure the server:

### Using multiples targets in Prometheus configuration

The server have a route to scrap the page and extract the metrics on demand.

```
$ curl http://localhost:3000/metrics?url=www.andersonba.com
```

Nice! Now you have to configure the targets in your `prometheus.yml`. [See example](./prometheus.yml#L12-L37)

#### URL params

| URL Param | Description | Type | Example |
|-----------|-------------|------|---------|
| `url` | **Required**. Page URL | `string` | `?url=google.com`
| `labels[]` | List of mapped labels | `Array<string>` | `?labels[]=page:anderson&labels[]=section:home`
| `mimeTypes[]` | List of mimeTypes to be filtered | `Array<string>` | `?mimeTypes[]=javascript&mimeTypes[]=css`

### Using a configuration file

If you don't prefer to put many targets in your prometheus configuration, you can configure a time-based job scheduler in the server. You just need to create a configuration file. [See example](config.example.yml)

Now you have to configure only one target in your `prometheus.yml` using path `/metrics` in the server URL, without params.

The server will scrap the pages every `1h`, but you can change it. [See configuration file](./config.example.yml).

| Attribute | Description | Type |
|-----------|-------------|------|
| `interval` | Interval time used in the job scheduler | number | 3600000 |
| `configurations` | List of pages to extract metrics | `Array<Configuration>` (See below)
| `labels` | List of common labels used in all page configurations | `{[name: string]: string}`
| `defaults` | Default values for the configuration objects
| `metricName` | Metric name used by Gauge collector.
| `enableOnDemandQuery` | Also enable on-demand scrapping (using query params, see above)


- `url` - **Required**. Page URL
- `metrics.file` - Boolean. Exports file metrics
- `metrics.count` - Boolean. Exports count metrics
- `metrics.size` - Boolean. Exports size metrics
- `metrics.gzip` - Boolean. Exports gzip metrics
- `metrics.countByMimeType` - Boolean. Exports countByMimeType metrics
- `metrics.sizeByMimeType` - Boolean. Exports sizeByMimeType metrics
- `metrics.gzipByMimeType` - Boolean. Exports gzipByMimeType metrics
- `labels` - Object. Mapped


```bash
docker run --name=prometheus-assets -d -p 3000:3000 andersonba/prometheus-assets
```

See below the two ways to configure the server:

#### Using a configuration file

Now, in your Prometheus configuration ([/etc/prometheus/prometheus.yml](https://prometheus.io/docs/prometheus/latest/configuration/configuration/)), add a new target.

You can monitor multiple URLs passing `params` each scrape config. [See example](prometheus/prometheus.yml#L12-L37)

If you prefer use a configuration file, create a [config.yml](prometheus/config.example.yml) file. Then, run the container defining
the volume:

```bash
docker run --name=prometheus-assets -v /tmp/config.yml:/app/prometheus/ -d -p 3000:3000 andersonba/prometheus-assets
```