/* eslint-disable no-console */
const yamlJs = require('yamljs');
const { merge } = require('lodash');
const { getEnv } = require('./utils');
const constants = require('../constants');

let settings = {
  path: getEnv('METRICS_PATH', '/metrics'),
  metricName: getEnv('METRIC_NAME', 'puppeteer_assets'),
  enableOnDemandQuery: getEnv('METRIC_ON_DEMAND_QUERY', false),
  defaults: {
    metrics: {
      file: getEnv('METRIC_FILE_ENABLED', true),
      count: getEnv('METRIC_COUNT_ENABLED', true),
      size: getEnv('METRIC_SIZE_ENABLED', true),
      gzip: getEnv('METRIC_GZIP_ENABLED', true),
      countByMimeType: getEnv('METRIC_COUNT_BY_MIMETYPE_ENABLED', true),
      sizeByMimeType: getEnv('METRIC_SIZE_BY_MIMETYPE_ENABLED', true),
      gzipSizeByMimeType: getEnv('METRIC_GZIP_SIZE_BY_MIMETYPE_ENABLED', true),
    },
    mimeTypes: getEnv('METRIC_MIMETYPES') ? getEnv('METRIC_MIMETYPES').split(',') : constants.defaultMimeTypes,
  },
  configurations: [],
};

try {
  settings = merge(
    {},
    settings,
    yamlJs.load(process.env.CONFIG_PATH || `${__dirname}/../config.yml`) || {},
  );
  console.info('> Using configuration file...');
} catch (e) {
  settings.enableOnDemandQuery = true;
  console.info('> No configuration file. On demand query enabled.');
}

module.exports = settings;
