/* eslint-disable no-console */
const yamlJs = require('yamljs');
const { merge } = require('lodash');
const { env } = require('./utils');
const constants = require('../constants');

let settings = {
  path: env('METRICS_PATH', '/metrics'),
  metricName: env('METRIC_NAME', 'puppeteer_assets'),
  enableOnDemandQuery: env('METRIC_ON_DEMAND_QUERY', false),
  defaults: {
    metrics: {
      file: env('METRIC_FILE_ENABLED', true),
      count: env('METRIC_COUNT_ENABLED', true),
      size: env('METRIC_SIZE_ENABLED', true),
      gzip: env('METRIC_GZIP_ENABLED', true),
      countByMimeType: env('METRIC_COUNT_BY_MIMETYPE_ENABLED', true),
      sizeByMimeType: env('METRIC_SIZE_BY_MIMETYPE_ENABLED', true),
      gzipSizeByMimeType: env('METRIC_GZIP_SIZE_BY_MIMETYPE_ENABLED', true),
    },
    mimeTypes: env('METRIC_MIMETYPES') ? env('METRIC_MIMETYPES').split(',') : constants.defaultMimeTypes,
  },
  configurations: [],
};

try {
  settings = merge(
    {},
    settings,
    yamlJs.load(env('CONFIG_PATH') || `${__dirname}/../config.yml`) || {},
  );
  console.info('> Using configuration file...');
} catch (e) {
  settings.enableOnDemandQuery = true;
  console.info('> No configuration file. On demand query enabled.');
}

module.exports = settings;
