/* eslint-disable no-console */
const yamlJs = require('yamljs');
const { merge } = require('lodash');
const { env } = require('./utils');
const constants = require('../constants');

function envToArray(key, otherwise = [], separator = ',') {
  const value = env(key);
  return value ? value.split(separator) : otherwise;
}

let settings = {
  path: env('METRICS_PATH', '/metrics'),
  metricName: env('METRIC_NAME', 'puppeteer_assets'),
  enableOnDemandQuery: env('METRICS_ON_DEMAND_QUERY', false),
  labels: envToArray('METRICS_LABELS', []),
  interval: env('METRICS_INTERVAL', 60 * 60 * 1000),
  defaults: {
    metrics: {
      file: env('METRICS_FILE_ENABLED', true),
      count: env('METRICS_COUNT_ENABLED', true),
      size: env('METRICS_SIZE_ENABLED', true),
      gzip: env('METRICS_GZIP_ENABLED', true),
      countByMimeType: env('METRICS_COUNT_BY_MIMETYPE_ENABLED', true),
      sizeByMimeType: env('METRICS_SIZE_BY_MIMETYPE_ENABLED', true),
      gzipSizeByMimeType: env('METRICS_GZIP_SIZE_BY_MIMETYPE_ENABLED', true),
    },
    mimeTypes: envToArray('METRICS_MIMETYPES', constants.defaultMimeTypes),
  },
  configurations: [],
};

try {
  settings = merge(
    {},
    settings,
    yamlJs.load(env('CONFIG_PATH') || `${__dirname}/../config.yml`) || {},
  );
  console.info('> Using configuration file...');
} catch (e) {
  settings.enableOnDemandQuery = true;
  console.info('> No configuration file. On demand query enabled.');
}

module.exports = settings;
